Learn R Programming

gscounts (version 0.1-4)

get_recruittimes: get_recruittimes

Description

Calculate the times subjects enter the study

Usage

get_recruittimes(accrual_period, n, accrual_exponent)

Arguments

accrual_period

numeric; duration of accrual period. Must be positive.

n

numeric; number of subjects recruited at end of accrual period.

accrual_exponent

numeric; exponent in sample size function \(f(t)\).

Details

Number of subjects in the study at study time t is given by f(t)=a * t^b with a = n / accrual_period. For linear recruitment, b=1. b > 1 results is slower than linear recruitment for t < accrual_period and faster than linear recruitment for t > accrual_period. b < 1 vice versa.